@@ -1,10 +1,14 @@
 package Code::TidyAll::Plugin::Go::Fmt;
-$Code::TidyAll::Plugin::Go::Fmt::VERSION = '0.02';
+
 use strict;
 use warnings;
 
-use IPC::Run3 qw( run3 );
+our $VERSION = '0.03';
+
 use Moo;
+use namespace::autoclean;
+
+use IPC::Run3 qw( run3 );
 
 extends 'Code::TidyAll::Plugin';
 
@@ -28,8 +32,8 @@ sub transform_file {
 
 sub _write_file {
     my ( $file, $contents ) = @_;
-    open( my $fh, ">", $file ) or die "could not open $file: $!";
-    print $fh $contents;
+    open( my $fh, '>', $file ) or die "could not open $file: $!";
+    print {$fh} $contents or die $!;
 }
 
 1;
