@@ -1,10 +1,14 @@
 package Code::TidyAll::Plugin::Go::Vet;
-$Code::TidyAll::Plugin::Go::Vet::VERSION = '0.02';
+
 use strict;
 use warnings;
 
-use IPC::Run3 qw( run3 );
+our $VERSION = '0.03';
+
 use Moo;
+use namespace::autoclean;
+
+use IPC::Run3 qw( run3 );
 
 extends 'Code::TidyAll::Plugin';
 
